@@ -1,6 +1,10 @@
+'''The warrior server.
+
+The warrior phones home to Warrior HQ
+(https://github.com/ArchiveTeam/warrior-hq).
+'''
 import json
 import subprocess
-import functools
 import os
 import os.path
 import shutil
@@ -8,25 +12,23 @@ import sys
 import datetime
 import time
 import re
-import json
 from ordereddict import OrderedDict
 from distutils.version import StrictVersion
 
 from tornado import ioloop
 from tornado import gen
-from tornado.ioloop import PeriodicCallback
-from tornado.httpclient import AsyncHTTPClient, HTTPRequest
+from tornado.httpclient import AsyncHTTPClient
 
 import seesaw
 from seesaw.event import Event
 from seesaw.externalprocess import AsyncPopen
 from seesaw.runner import Runner
 from seesaw.config import realize
-from seesaw.web import SeesawConnection
 from seesaw.config import NumberConfigValue, StringConfigValue, ConfigValue
 
 
 class ConfigManager(object):
+    '''Manages the configuration.'''
     def __init__(self, config_file):
         self.config_file = config_file
         self.config_memory = {}
@@ -77,6 +79,7 @@ class ConfigManager(object):
 
 
 class BandwidthMonitor(object):
+    '''Extracts the bandwidth usage from the system stats.'''
     devre = re.compile(r"^\s*([a-z0-9]+):(.+)$")
 
     def __init__(self, device):
@@ -134,6 +137,7 @@ class BandwidthMonitor(object):
 
 
 class Warrior(object):
+    '''The warrior god object.'''
     def __init__(self, projects_dir, data_dir, warrior_hq_url, real_shutdown=False, keep_data=False):
         if not os.access(projects_dir, os.W_OK):
             raise Exception("Couldn't write to projects directory: %s" % projects_dir)
